``Type1Font`` objects now decrypt the encrypted part
----------------------------------------------------

Type 1 fonts have a large part of their code encrypted as an obsolete
copy-protection measure. This part is now available decrypted as the
``decrypted`` attribute of :class:`~matplotlib.type1font.Type1Font`.
This decrypted data is not yet parsed, but this is a prerequisite for
implementing subsetting.
